<template>
  <view class="page pt-2">
    <CardTitle title="钢芯领用" :hideAction="true" @action="addReport" />
    <view class="list">
      <wd-card v-for="(item, index) in 2" :key="index" type="rectangle" custom-class="round">
        <template #title>
          <view class="flex justify-between">
            <view>
              <wd-icon name="a-rootlist" color="#0D867F"></wd-icon>
              <text class="text-[#252525] ml-2 font-medium">JX28201021-1</text>
            </view>
            <view class="text-[#A8A8A8]" @click="toEdit">编辑</view>
          </view>
        </template>
        <ProductionCard :data="cardAttr" color="#0D867F" />
      </wd-card>
    </view>
    <wd-popup v-model="dialog.visible" position="bottom" custom-class="yl-popup">
      <view class="action px-3">
        <wd-button type="text" @click="cancel">取消</wd-button>
        <wd-button type="text" @click="submit">确定</wd-button>
      </view>
      <PlateForm />
    </wd-popup>
    <wd-toast />
  </view>
</template>

<script setup lang="ts">
import CardTitle from "@/components/card-title/index.vue";
import ProductionCard from "../../../components/ProductionCard.vue";
import { useToast } from "wot-design-uni";
import PlateForm from "./form.vue";

const toast = useToast();
const dialog = reactive({
  visible: false,
});

const cardAttr = ref<any[]>([
  {
    label: "盘号",
    value: "1902101",
  },
  {
    label: "长度",
    value: "46kg",
  },
  {
    label: "重量",
    value: "10kg",
  },
  {
    label: undefined,
    value: undefined,
  },
  {
    label: "厂家",
    value: "江苏省南通市芯导数字厂",
    span: 14,
  },
]);

const toEdit = () => {
  uni.navigateTo({
    url: "/pages/production/twist/receive/steelCore/edit",
  });
};

const addReport = () => {
  dialog.visible = true;
};

const submit = () => {
  toast.show("提交");
  dialog.visible = false;
};

const cancel = () => {
  toast.show("取消");
  dialog.visible = false;
};
</script>

<style lang="scss" scoped>
.page {
  background: #f3f9f8;
  .list {
    height: calc(100vh - 120px);
    margin: 12px;
    overflow: scroll;

    :deep() {
      .round {
        border-radius: 4px;
      }
    }
  }
}

.action {
  display: flex;
  justify-content: space-between;
}
</style>
